@@ -182,7 +182,7 @@ class Poset:
         from pydotplus import graph_from_edges
         from pydotplus.graphviz import Node, Edge
 
-        color = '#333333' if extra_edges is not None else '#666666'
+        color = '#555555' if extra_edges is None else '#888888'
 
         g = graph_from_edges([], directed=True)
         g.set_rankdir('BT')
